{% extends 'manageBase.html' %}

{% block webtitle %}{{_("manage")}} > {{ modelName }}{% end %}

{% block header %}
<link href="{{ static_url('css/light-custome.css') }}" rel="stylesheet">

<!-- chart.js -->
<script src="//cdn.bootcss.com/echarts/3.3.1/echarts.js"></script>
<!--<script src="//cdn.bootcss.com/echarts/3.3.1/echarts.common.js"></script>-->
<!--<script src="//cdn.bootcss.com/echarts/3.3.1/extension/dataTool.min.js"></script>
<script src="//cdn.bootcss.com/echarts/3.3.1/extension/bmap.min.js"></script>-->
<!--<script src="//cdn.bootcss.com/echarts/3.3.1/echarts.simple.min.js"></script>-->

<!-- vue -->
<script src="//cdn.bootcss.com/vue/2.1.4/vue.js"></script>

<!-- font awesome -->
<link href="//cdn.bootcss.com/font-awesome/4.7.0/css/font-awesome.min.css" rel="stylesheet">

<!--dataTable-->
<!--<link rel="stylesheet" type="text/css" href="https://cdn.datatables.net/v/bs/jszip-2.5.0/pdfmake-0.1.18/dt-1.10.13/af-2.1.3/b-1.2.4/b-colvis-1.2.4/b-flash-1.2.4/b-html5-1.2.4/b-print-1.2.4/cr-1.3.2/fc-3.2.2/fh-3.1.2/kt-2.2.0/r-2.1.0/rr-1.2.0/sc-1.4.2/se-1.2.0/datatables.min.css"/>

<script type="text/javascript" src="https://cdn.datatables.net/v/bs/jszip-2.5.0/pdfmake-0.1.18/dt-1.10.13/af-2.1.3/b-1.2.4/b-colvis-1.2.4/b-flash-1.2.4/b-html5-1.2.4/b-print-1.2.4/cr-1.3.2/fc-3.2.2/fh-3.1.2/kt-2.2.0/r-2.1.0/rr-1.2.0/sc-1.4.2/se-1.2.0/datatables.min.js"></script>
-->
<!--<link href="//cdn.bootcss.com/datatables/1.10.13/css/jquery.dataTables.min.css" rel="stylesheet">
<link href="//cdn.bootcss.com/datatables/1.10.13/css/dataTables.bootstrap.min.css" rel="stylesheet">

<script src="//cdn.bootcss.com/datatables/1.10.13/js/jquery.dataTables.min.js"></script>
<script src="//cdn.bootcss.com/datatables/1.10.13/js/dataTables.bootstrap.min.js"></script>-->
<!-- i check -->
<link href="//cdn.bootcss.com/iCheck/1.0.2/skins/all.css" rel="stylesheet">

<script src="//cdn.bootcss.com/iCheck/1.0.2/icheck.min.js"></script>

{% end %}

{% block content %}


{# {% include 'leftSideBar.html' %} #}

<!-- start new content-->
<div class="content-wrapper">
    <div class="row">
        <div class="col-md-12">
            <div class="content-header">
                <h1>
                    {{_("data management")}}
                </h1>
                <ol class="breadcrumb">
                    <li><a href="{{ reverse_url('tjango.contrib.admin.views.adminManageHandler') }}"><i class="fa fa-dashboard"></i> {{_("management")}}</a></li>
                    <li><a href="#"><i class="fa fa-server "></i> {{ package }}</a></li>
                    <li><i class="fa fa-database "></i> {{ modelName }}</li>
                    <li class="active"><i class="fa fa-sticky-note">{{_("Add or change data")}}</i> </li>
                </ol>
            </div>

            <div class="content body">
                <div class="row">
                    <div class="col-md-10 col-md-offset-1">
                        <form action="{{ reverse_url('tjango.contrib.admin.views.appModelChangeManager',modelName,id) }}" method="post">
                        {% include 'change_data_block.html' %}
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

{% end %}

{% block footerJS %}
<script>
    function getBodyStyle(){
        var regex = /skin-(\w+)(-?).*?/;
        var className = $('body')[0].className;
        var color = className.match(regex);
        if(color.length && color[1] !='black'){
            return '-'+color[1];
        }
        else{
            // use default if not find
            return '';
        }
    }

    $(document).ready(function(){
        $('input').iCheck({
            checkboxClass: 'icheckbox_flat'+getBodyStyle(),
            radioClass: 'iradio_flat'+getBodyStyle()
        });
    });
</script>
{% end %}