<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <meta name="description" content="{{_('dashboard')}}">
    <meta name="author" content="npuacm">
    <meta name="keyword" content="administrator">

    <title>{% block webtitle %}{% end %} | {{_('dashboard')}}</title>
    <!-- jQuery -->
    <script src="//cdn.bootcss.com/jquery/2.2.3/jquery.min.js"></script>

    <!-- tether -->
    <!--<link href="//cdn.bootcss.com/tether/1.3.7/css/tether.min.css" rel="stylesheet">
    <script src="//cdn.bootcss.com/tether/1.3.7/js/tether.min.js"></script>-->

    <!-- bootstrap -->
    <link href="//cdn.bootcss.com/bootstrap/3.3.7/css/bootstrap.min.css" rel="stylesheet">
    <script src="//cdn.bootcss.com/bootstrap/3.3.7/js/bootstrap.min.js"></script>

    <!-- admin LTE -->
    <link href="//cdn.bootcss.com/admin-lte/2.3.7/css/AdminLTE.min.css" rel="stylesheet">
    <link href="//cdn.bootcss.com/admin-lte/2.3.7/css/skins/_all-skins.min.css" rel="stylesheet">

    <!--<script src="//cdn.bootcss.com/admin-lte/2.3.8/js/pages/dashboard.js"></script>-->

    <!-- custome -->
    <link href="{{ static_url('css/manageStyle.css') }}" rel="stylesheet">

    <!--jquery cookie -->
    <script src="//cdn.bootcss.com/jquery-cookie/1.4.1/jquery.cookie.js"></script>

    <link href="//cdn.bootcss.com/toastr.js/latest/css/toastr.min.css" rel="stylesheet">

    <!-- font awesome -->
    <link href="//cdn.bootcss.com/font-awesome/4.7.0/css/font-awesome.min.css" rel="stylesheet">

    {% block header %}

    {% end %}
</head>
<body class="skin-blue hold-transition sidebar-mini" data-spy="scroll" data-target="#scrollspy">
<div class="wrapper">
    {# show cookie notification #}
    {#% include 'cookieNotification.html' %#}
    {% include 'navbar.html' %}

    {% module adminlte_load_left_sidebar() %}


    {% block content %}

    {% end %}


    {% block footerJS %}

    {% end %}
    <script>
        var AdminLTEOptions = {
            //Add slimscroll to navbar menus
            //This requires you to load the slimscroll plugin
            //in every page before app.js
            navbarMenuSlimscroll: true,
            navbarMenuSlimscrollWidth: "3px", //The width of the scroll bar
            navbarMenuHeight: "200px", //The height of the inner menu
            //General animation speed for JS animated elements such as box collapse/expand and
            //sidebar treeview slide up/down. This options accepts an integer as milliseconds,
            //'fast', 'normal', or 'slow'
            animationSpeed: 500,
            //Sidebar push menu toggle button selector
            sidebarToggleSelector: "[data-toggle='offcanvas']",
            //Activate sidebar push menu
            sidebarPushMenu: true,
            //Activate sidebar slimscroll if the fixed layout is set (requires SlimScroll Plugin)
            sidebarSlimScroll: true,
            //Enable sidebar expand on hover effect for sidebar mini
            //This option is forced to true if both the fixed layout and sidebar mini
            //are used together
            sidebarExpandOnHover: false,
            //BoxRefresh Plugin
            enableBoxRefresh: true,
            //Bootstrap.js tooltip
            enableBSToppltip: true,
            BSTooltipSelector: "[data-toggle='tooltip']",
            //Enable Fast Click. Fastclick.js creates a more
            //native touch experience with touch devices. If you
            //choose to enable the plugin, make sure you load the script
            //before AdminLTE's app.js
            enableFastclick: true,
            //Control Sidebar Options
            enableControlSidebar: true,
            controlSidebarOptions: {
                //Which button should trigger the open/close event
                toggleBtnSelector: "[data-toggle='control-sidebar']",
                //The sidebar selector
                selector: ".control-sidebar",
                //Enable slide over content
                slide: true
            },
            //Box Widget Plugin. Enable this plugin
            //to allow boxes to be collapsed and/or removed
            enableBoxWidget: true,
            //Box Widget plugin options
            boxWidgetOptions: {
                boxWidgetIcons: {
                    //Collapse icon
                    collapse: 'fa-minus',
                    //Open icon
                    open: 'fa-plus',
                    //Remove icon
                    remove: 'fa-times'
                },
                boxWidgetSelectors: {
                    //Remove button selector
                    remove: '[data-widget="remove"]',
                    //Collapse button selector
                    collapse: '[data-widget="collapse"]'
                }
            },
            //Direct Chat plugin options
            directChat: {
                //Enable direct chat by default
                enable: true,
                //The button to open and close the chat contacts pane
                contactToggleSelector: '[data-widget="chat-pane-toggle"]'
            },
            //Define the set of colors to use globally around the website
            colors: {
                lightBlue: "#3c8dbc",
                red: "#f56954",
                green: "#00a65a",
                aqua: "#00c0ef",
                yellow: "#f39c12",
                blue: "#0073b7",
                navy: "#001F3F",
                teal: "#39CCCC",
                olive: "#3D9970",
                lime: "#01FF70",
                orange: "#FF851B",
                fuchsia: "#F012BE",
                purple: "#8E24AA",
                maroon: "#D81B60",
                black: "#222222",
                gray: "#d2d6de"
            },
            //The standard screen sizes that bootstrap uses.
            //If you change these in the variables.less file, change
            //them here too.
            screenSizes: {
                xs: 480,
                sm: 768,
                md: 992,
                lg: 1200
            }
        };

    </script>
    <script src="//cdn.bootcss.com/admin-lte/2.3.8/js/app.min.js"></script>


</div>
<script src="//cdn.bootcss.com/admin-lte/2.3.8/js/demo.js"></script>
<script src="//cdn.bootcss.com/toastr.js/latest/toastr.min.js"></script>
</body>
</html>