.top-nav {
    background-color: #fff;
    -webkit-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.05);
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.05);
    border: 0;
    width: 100%;
    z-index: 2;
    padding: 10px;
    border-radius: 0;
}

.top-nav .navbar-brand {
    font-weight: 300;
    color: rgba(0, 0, 0, 0.3);
}

.top-nav .navbar-toggle {
    border-radius: 0.2rem;
    border: 0;
}

.top-nav .navbar-brand{
    padding-top: .425rem;
    padding-bottom: .425rem;
}

.top-nav .navbar-nav > li > a {
    color: rgba(0, 0, 0, 0.3);
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -webkit-transition: all 0.3s ease;
    transition: all 0.3s ease;
}

.top-nav .navbar-nav > li > a:hover {
    color: rgba(0, 0, 0, 0.8);
}

.nav-stacked > li {
    float: left;
}

.nav-stacked > li > a{
    border-radius: 0;
    font-size: 0.75rem;
}

.nav-stacked > li > a:hover,
.nav-stacked > li > a:focus {
    text-decoration: none;
    background-color: rgb(227, 245, 251);
}

.nav-stacked > li.active > a,
.nav-stacked > li.active > a:hover,
.nav-stacked > li.active > a:focus {
    color: #ffffff;
    background-color: #1ca8dd;
}

.nav-stacked > li + li{
    margin-top: 0.2rem;
    margin-left: 0.25rem;
}

.stacked-list > li.list-group-item:hover{
    background-color: rgba(204, 204, 204,0.8);
}

.stacked-list.list-group > .list-group-item{
    background: rgba(256,256,256,0.3);
    border: 0;
}

.stacked-list.list-group > .list-group-item > .list-group-progress {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    z-index: -1;
    display: block;
    background-color: #B5FF7D;
}

.color-line {
    background: #f7f9fa;
    height: 6px;
    background-image: -webkit-linear-gradient(left, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-image: -moz-linear-gradient(left, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-image: -ms-linear-gradient(left, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-image: linear-gradient(to right, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-size: 100% 6px;
    background-position: 50% 100%;
    background-repeat: no-repeat;
}