{% extends 'base.html' %}

{% block webtitle %}{{_("login")}}{% end %}

{% block header %}



{% end %}

{% block content %}
<!-- login background -->
<div class="container-fluid login-background">

    <div class="row login-chart">
        <div class="col-md-3 col-lg-5">
            <h2 class="title text-right">{{_("login")}}</h2>
            <h6 class="title text-right">{% module get_option('SITE_NAME') %}</h6>


        </div>
        <div class="col-md-8 col-lg-6 ">
            <form action="{{ reverse_url('tjango.contrib.admin.views.authRequestHandler') }}" method="post">
                <div class="login-form">
                    <div class="form-group">
                        {% if handler.get_current_user() %}
                        <script>
                            $(document).ready(function() {
                                setTimeout(function() {
                                    toastr.options = {
                                        closeButton: true,
                                        progressBar: true,
                                        showMethod: 'slideDown',
                                        timeOut: 10000
                                    };
                                    toastr.success( '{{_("You could directly login the dashboard.")}}','{{_("logined.")}}');
                                }, 1300)}
                            );
                        </script>
                            <p>{{_("Use account")}}<a href="{{ reverse_url('tjango.contrib.admin.views.adminManageHandler')  }}">{{ handler.get_current_user().nickname }}</a> {{_('login')}}</p>
                        {% end %}
                    </div>


                    {% raw xsrf_form_html() %}
                    <div class="form-group">
                        <input type="text" class="form-control login-field" name="username" value="" placeholder="{{_('username')}}" id="login-name" />
                        <label class="login-field-icon fui-user" for="login-name"></label>
                    </div>

                    <div class="form-group">
                        <input type="password" class="form-control login-field" name="password" value="" placeholder="{{_('password')}}" id="login-pass" />
                        <label class="login-field-icon fui-lock" for="login-pass"></label>
                    </div>

                    <button class="btn btn-primary btn-lg btn-block" href="#">{{_("login")}}</button>
                    <a class="login-link" href="#">{{_("forget password?")}}</a>
                </div>
            </form>

        </div>
    </div>
</div>


{% end %}

{% block footerJS %}


{% end %}