/* font from Google */
/*@import url('https://fonts.googleapis.com/css?family=Exo+2');*/
@import url('https://fonts.googleapis.com/css?family=Josefin+Sans');
@import url('https://fonts.googleapis.com/css?family=Roboto');
@import url('https://fonts.googleapis.com/css?family=Oxygen');

/* responsive layout */
img,
canvas,
iframe,
video,
svg
{
    max-width: 100%;
}

body,input,select,option {
    font-family: 'Roboto', "微软雅黑", sans-serif;
}

h1,
h2,
h3,
h4,
h5,
h6{
    font-weight: 300;
    font-family: 'Josefin Sans', "微软雅黑", sans-serif;
}
p,
a,
span{
    font-family: 'Oxygen', "微软雅黑", sans-serif;
    font-weight: 300;
}

.login-background {
    min-height: 100% !important;
    background: #1abc9c;
}

.login-background .title
{
    color: #f9f2f4;
}

.login-chart {
    padding: 10rem 0.5rem 20rem 0.5rem;
}

.color-line {
    background: #f7f9fa;
    height: 6px;
    background-image: -webkit-linear-gradient(left, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-image: -moz-linear-gradient(left, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-image: -ms-linear-gradient(left, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-image: linear-gradient(to right, #34495e, #34495e 25%, #9b59b6 25%, #9b59b6 35%, #3498db 35%, #3498db 45%, #62cb31 45%, #62cb31 55%, #ffb606 55%, #ffb606 65%, #e67e22 65%, #e67e22 75%, #e74c3c 85%, #e74c3c 85%, #c0392b 85%, #c0392b 100%);
    background-size: 100% 6px;
    background-position: 50% 100%;
    background-repeat: no-repeat;
}