<header class="main-header">
    <a href="{{ reverse_url('tjango.contrib.admin.views.adminManageHandler') }}" class="logo">
        <span class="logo-mini"><b>T</b>jango</span>
        <span class="logo-lg"><b>Tornado</b>jango</span>
    </a>
    <!-- Header Navbar: style can be found in header.less -->
    <nav class="navbar navbar-static-top" role="navigation">
        <!-- Sidebar toggle button-->
          <a href="#" class="sidebar-toggle" data-toggle="offcanvas" role="button">
            <span class="sr-only">Toggle navigation</span>
          </a>
        <!-- Navbar Right Menu -->
        <div class="navbar-custom-menu">
            <ul class="nav navbar-nav">
                <!--setting -->
                <li class="dropdown notifications-menu">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                        <i class="fa fa-gear"></i>
                        <span class="label label-warning">8</span>
                    </a>
                    <ul class="dropdown-menu">
                        <li class="header">{{_("Style")}}</li>
                        <li>
                            <!-- inner menu: contains the actual data -->
                            <ul class="menu" id="layout-skins-list">
                                <li>
                                    <a href="#" data-skin="skin-blue">
                                        <i class="fa fa-users text-aqua"></i>  {{_("dark")}}{{_("aqua")}}
                                    </a>
                                </li>
                                <li>
                                    <a href="#" data-skin="skin-blue-light">
                                        <i class="fa fa-users text-aqua"></i> {{_("light")}}{{_("aqua")}}
                                    </a>
                                </li>

                                <li>
                                    <a href="#" data-skin="skin-yellow">
                                        <i class="fa fa-users text-yellow"></i> {{_("dark")}}{{_("yellow")}}
                                    </a>
                                </li>
                                <li>
                                    <a href="#" data-skin="skin-yellow-light">
                                        <i class="fa fa-users text-yellow"></i> {{_("light")}}{{_("yellow")}}
                                    </a>
                                </li>

                                <li>
                                    <a href="#" data-skin="skin-green">
                                        <i class="fa fa-users text-green"></i> {{_("dark")}}{{_("green")}}
                                    </a>
                                </li>
                                <li>
                                    <a href="#" data-skin="skin-green-light">
                                        <i class="fa fa-users text-green"></i> {{_("light")}}{{_("green")}}
                                    </a>
                                </li>

                                <li>
                                    <a href="#" data-skin="skin-purple">
                                        <i class="fa fa-users text-purple"></i> {{_("dark")}}{{_("purple")}}
                                    </a>
                                </li>
                                <li>
                                    <a href="#" data-skin="skin-purple-light">
                                        <i class="fa fa-users text-purple"></i> {{_("light")}}{{_("purple")}}
                                    </a>
                                </li>

                                <li>
                                    <a href="#" data-skin="skin-red">
                                        <i class="fa fa-users text-red"></i> {{_("dark")}}{{_("red")}}
                                    </a>
                                </li>
                                <li>
                                    <a href="#" data-skin="skin-red-light">
                                        <i class="fa fa-users text-red"></i> {{_("light")}}{{_("red")}}
                                    </a>
                                </li>

                                <li>
                                    <a href="#" data-skin="skin-black">
                                        <i class="fa fa-users text-black"></i> {{_("dark")}}{{_("black")}}
                                    </a>
                                </li>
                                <li>
                                    <a href="#" data-skin="skin-black-light">
                                        <i class="fa fa-users text-black"></i> {{_("light")}}{{_("black")}}
                                    </a>
                                </li>

                            </ul>
                        </li>
                        <li class="footer"><a href="#">{{_("dark")}}{{_("aqua")}}</a></li>
                    </ul>
                </li>


                <!-- Messages: style can be found in dropdown.less-->
                {# <li class="dropdown messages-menu">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                        <i class="fa fa-envelope-o"></i>
                        <span class="label label-success">4</span>
                    </a>
                    <ul class="dropdown-menu">
                        <li class="header">You have 4 messages</li>
                        <li>
                            <!-- inner menu: contains the actual data -->
                            <ul class="menu">
                                <li><!-- start message -->
                                    <a href="#">
                                        <div class="pull-left">
                                            <img src="//cdn.bootcss.com/admin-lte/2.3.8/img/user2-160x160.jpg" class="img-circle" alt="User Image">
                                        </div>
                                        <h4>
                                            Sender Name
                                            <small><i class="fa fa-clock-o"></i> 5 mins</small>
                                        </h4>
                                        <p>Message Excerpt</p>
                                    </a>
                                </li><!-- end message -->
                                ...
                            </ul>
                        </li>
                        <li class="footer"><a href="#">See All Messages</a></li>
                    </ul>
                </li>
                <!-- Notifications: style can be found in dropdown.less -->
                <li class="dropdown notifications-menu">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                        <i class="fa fa-bell-o"></i>
                        <span class="label label-warning">10</span>
                    </a>
                    <ul class="dropdown-menu">
                        <li class="header">You have 10 notifications</li>
                        <li>
                            <!-- inner menu: contains the actual data -->
                            <ul class="menu">
                                <li>
                                    <a href="#">
                                        <i class="ion ion-ios-people info"></i> Notification title
                                    </a>
                                </li>
                                ...
                            </ul>
                        </li>
                        <li class="footer"><a href="#">View all</a></li>
                    </ul>
                </li>
                <!-- Tasks: style can be found in dropdown.less -->
                <li class="dropdown tasks-menu">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                        <i class="fa fa-flag-o"></i>
                        <span class="label label-danger">9</span>
                    </a>
                    <ul class="dropdown-menu">
                        <li class="header">You have 9 tasks</li>
                        <li>
                            <!-- inner menu: contains the actual data -->
                            <ul class="menu">
                                <li><!-- Task item -->
                                    <a href="#">
                                        <h3>
                                            Design some buttons
                                            <small class="pull-right">20%</small>
                                        </h3>
                                        <div class="progress xs">
                                            <div class="progress-bar progress-bar-aqua" style="width: 20%" role="progressbar" aria-valuenow="20" aria-valuemin="0" aria-valuemax="100">
                                                <span class="sr-only">20% Complete</span>
                                            </div>
                                        </div>
                                    </a>
                                </li><!-- end task item -->
                                ...
                            </ul>
                        </li>
                        <li class="footer">
                            <a href="#">View all tasks</a>
                        </li>
                    </ul>
                </li>
                #}
                <!-- User Account: style can be found in dropdown.less -->
                <li class="dropdown user user-menu">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                        <img src="//cdn.bootcss.com/admin-lte/2.3.8/img/user2-160x160.jpg" class="user-image" alt="User Image">
                        <span class="hidden-xs">{{ handler.get_current_user().nickname }}</span>
                    </a>
                    <ul class="dropdown-menu">
                        <!-- User image -->
                        <li class="user-header">
                            <img src="//cdn.bootcss.com/admin-lte/2.3.8/img/user2-160x160.jpg" class="img-circle" alt="User Image">
                            <p>
                                {{ handler.get_current_user().username }}
                                <small>{{ handler.get_current_user().register_time }}</small>
                            </p>
                        </li>
                        <!-- Menu Body -->
                        <li class="user-body">
                            <div class="col-xs-4 text-center">
                                <a href="#">Followers</a>
                            </div>
                            <div class="col-xs-4 text-center">
                                <a href="#">Following</a>
                            </div>
                            <div class="col-xs-4 text-center">
                                <a href="#">Star</a>
                            </div>
                        </li>
                        <!-- Menu Footer-->
                        <li class="user-footer">
                            <div class="pull-left">
                                <a href="#" class="btn btn-default btn-flat">{{_("Profile")}}</a>
                            </div>
                            <div class="pull-right">
                                <a href="#" class="btn btn-default btn-flat">{{_("Sign out")}}</a>
                            </div>
                        </li>
                    </ul>
                </li>
                <!-- Control Sidebar Toggle Button -->
                <li>
                    <a href="#" data-toggle="control-sidebar"><i class="fa fa-gears"></i></a>
                </li>
            </ul>
        </div>
    </nav>
</header>

<script src="{{ static_url('js/manage/manage.js') }}"></script>
