<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <meta name="description" content='{{_("dashboard")}}'>
    <meta name="author" content="npuacm">
    <meta name="keyword" content="administrator">

    <title>{% block webtitle %}{% end %} | {{_("dashboard")}}</title>
    <!-- jQuery -->
    <script src="//cdn.bootcss.com/jquery/2.2.3/jquery.min.js"></script>

    <!-- tether -->
    <!--<link href="//cdn.bootcss.com/tether/1.3.7/css/tether.min.css" rel="stylesheet">
    <script src="//cdn.bootcss.com/tether/1.3.7/js/tether.min.js"></script>-->

    <!-- bootstrap -->
    <link href="//cdn.bootcss.com/bootstrap/4.0.0-alpha/css/bootstrap.min.css" rel="stylesheet">
    <script src="//cdn.bootcss.com/bootstrap/4.0.0-alpha/js/bootstrap.min.js"></script>


    <!-- flat-UI -->
    <link href="//cdn.bootcss.com/flat-ui/2.3.0/css/flat-ui.min.css" rel="stylesheet">
    <script src="//cdn.bootcss.com/flat-ui/2.3.0/js/flat-ui.min.js"></script>

    <!-- custome -->
    <link href="{{ static_url('css/style.css') }}" rel="stylesheet">

    <!--jquery cookie -->
    <script src="//cdn.bootcss.com/jquery-cookie/1.4.1/jquery.cookie.js"></script>

    <link href="//cdn.bootcss.com/toastr.js/latest/css/toastr.min.css" rel="stylesheet">
    <script src="//cdn.bootcss.com/toastr.js/latest/toastr.min.js"></script>

    {% block header %}

    {% end %}
</head>
<body>
{# show cookie notification #}
{% include 'cookieNotification.html' %}

{% block content %}

{% end %}


{% block footerJS %}

{% end %}
</body>
</html>